bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift A ## 30. Aventiure
___________________________________________________ #### <Wie si der schiltwaht phlagen>
| ### er tach hete nv ende vn– nahet in div naht ### die wegemveden reken ir sorge an ### wan si solden rvowen vn– an ir bette gan ### daz bereitte Hagne ez wart in schiere kvnt getan
###### 1757 | ### Gvnther sprach ze dem wirte got laze ivch wol gelben ### wir wellen varn slafen ir svlt vns vrlop geben ### swenn ir daz gebietet so kome wir morgen frvo ### er schiet von sinen gesten harte vroelichen do
###### 1758 | ### Dringen allenthalben die geste man do sach ### Volker der kvene zvo den Hvnen sprach ### wie getvrret ir den reken fvr die fveze gan ### vn– welt ir ivchs niht miden so wirt iv leide getan
###### 1759 | ### So slah ich eteslichem so swern gigen slach ### hat er getriwen iemen daz erz beweinen mac ### wan wihet ir vns rechen ia dvnchet ez mich gvot ### ez heizent allez degne vn– sint geliche niht gemvot
###### 1760 | ### Do der videlere so zorneclichen sprach ### Hagne der kvene hinder sich do sach ### er sprach iv ratet rehte der kvene spilman ### ir <Kriemhilde> helde svlt ze herberge gan
###### 1761 | ### Dez ir da habet gedingen ich wene ez iemen tvo ### welt ir iht bebinnen so komet vns morgen vrvo ### vn– lat vns ellenden heint haben gemach ### ia wen ez von helden mit solhem willen ie gesachach
###### 1762 | ### Do brahte man die geste in einen witen sal ### den fvnden si berihtet den reken vber al ### mit vil richen betten lanch vnd breit ### in riet vrov Kriemhilt div aller groezisten leit
###### 1763 | ### Manigen kolter spehe von Arraz man da sach ### der vil liehten pfelle vn– manich bettedach ### von arabischen siden die beste mohten sin ### dar vfe lagen listen die gaben herlichen schin
###### 1764 | ### Dechlachen hermin vil manigiv man da sach ### vn– von swarzem zobele darvnder si ir gemach ### des nahtes schaffen solden vntz an den liehten tac ### ein kvnich mit sime gesinde nie so herlich gelach
###### 1765 | ### Owe der nahtselde sprach Gyselhere daz kint ### vnd owe miner vrivnde die mit vns komen sint ### swie et ez min swester so gvetlich erbot ### ich fvrhte daz wir mvezen alle von ir schvlde ligen tot
###### 1766 | ### Nv lat iwer sorgen sprach Hagne der degne ### ich wil noh heint selbe der schiltwache phlegen ### ich trowe ich wol behveten vntz vns kvmet der tach ### des sit gar an angest so wend ez danne swer der mach
###### 1767 | ### Do nigen si im alle vn– seiten im des danch [72a] ### si giengen zvo den betten div wile <waz> niht lanch ### daz sich geleit heten die wetlichen man ### Hagne der chvene der helt sich wafen began
###### 1768 | ### Do sprach der videler Volker der degen ### versmahetez iv niht Hagne so wold mit iv phegen ### heint der schiltwach vntz morgen vrvo ### der helt vil minneclichen dancte Volker dvo
###### 1769 | ### Nv lon iv got von himel vil lieber Volker ### ze allen minen sorgen so engerte ich niemen mer ### niwan ivch aleine swa ich hete not ### ich sol ez wol verdienen mich enwendes der tot
###### 1770 | ### Do garten si sich bede in liehtez ir gewant ### do nam ir ietweder den schilt an sein hant ### vn– giengen vz dem hvse fvr die tvr stan ### do phlagen si der geste daz waz mit triwen getan
###### 1771 | ### Volker der snelle zvo dez sales want ### sinen schilt den gvoten laint er von der hant ### do gie er hin widere sein gigen er genam ### do diend er sinen vrivnden als ez dem helde gezam
###### 1772 | ### Vnder die tvre dez hvzes saz er vf den stæin ### kvener videlere wart noch nie dehein ### do im der seiten do so svezlich erclanch ### die stolzen ellenden die seitens Volker danch
###### 1773 | ### Do chlvngen sein sæiden daz al daz hvz erdoz ### sin ellen zvo der fvoge div warn beidiv groz ### svezzen vn– <senfter> gigen er began ### do entswebete er an den beten vil manigen sorgenden man
###### 1774 | ### Do si entslafen warn vn– er daz ervant ### do nam der degen widere den schilt an die hant ### vn– gie vz dem gadme fvr den tvrn stan ### vn– hvote der ellende vor den Kriemilde man
###### 1775 | ### Dez nahtes wol enmitten ine weiz ez e geschach ### daz Volker der kvene schinen helmen sach ### verre vz einer vinster die <Kriemhilde> man ### wolden an den gesten schaden gerne han getan
###### 1776 | ### Do sprach der videlere vrivmt her Hagne ### vns zimet disiv sorge ensamt ze tragne ### ich sihe gewafent Ivte vor dem hvse sten ### als ich mich versinne si wellent vns besten
###### 1777 | ### So swiget sprach do Hagne lat si her naher baz ### e si vnser werden innen so wirt hie helmevaz ### verruchet mit den swerten von vnser zweier hant ### si werdent Chriemhilde hin wider vil vbel gesant
###### 1778 | ### Ein der Hvnen reken vil schiere daz geschach ### daz div tvr waz behvetet wie balde er do sprach ### des wir da heten willen ia enmag es niht ergan ### ich sihe den videlere an der schiltwache stan
###### 1779 | ### Der treit vf sime hovbte einen helmen glantz [72b] ### lvter vnd herte starch vnd gantz ### ovch lohent im die ringe sam daz viwer tvot ### bi im stet ovch Hagne des sint die geste wol behvot
###### 1780 | ### Zehant si cherten wider do Volker daz ersach ### wider sinen gesellen er zorneclichen sprach ### nv lat mich zvo den reken von dem hvse gan ### ich wil vragen mere der vrowen Kriemhilde man
###### 1781 | ### Nein dvrh min liebe sprach do Hagne ### komet ir von dem hvse die snellen degne ### bringent ivch mit swerten lihte in solhe not ### daz ich iv mvese helfen vn– wer ez aller miner mage tot
###### 1782 | ### So wir danne beide komen in den strit ### ir zwene oder fier in einer kvrzen zit ### sprvngen zvo dem hvse vn– teten vns div lait ### an den slafenden div nimmer wurden verchlæit
###### 1783 | ### Do sprach aber Volker so lat daz geschehen ### daz wir si bringen innen daz wir si han gesehen ### daz dez iht lovgnen Kriemhilde man ### daz si vngetrivlich vil gerne heten getan
###### 1784 | ### Zehant do rief in Volker hin engene ### wez get ir svs gewafent snelle degne ### welt ir schachen riten Kriemhilde man ### dar svlt ir mich ze helfe vn– minen hergesellen han
###### 1785 | ### Dez antwurte im niemen zornich waz sin mvot ### phi ir zagen boez sprach der helt gvot ### woldet ir slafende vns ermordert han ### daz ist so gvoten helden noch vil selten her getan
###### 1786 | ### Do wart der kvniginne vil rehte daz geseit ### daz ir boten niht wurben von schvlden waz ir lait ### do fvogte si ez anders vil grimmech waz ir mvot ### dez mvosen sit verderben helde kvene vnd gvot

<<< Übersicht <<< vorige Seite nächste Seite >>>